@@ -335,22 +335,23 @@ class Zone(NetBoxModel):
                 .exists()
             ):
                 raise ValidationError(
-                    {"name": "A zone with name %(name)s and no view already exists."},
-                    params={"name": self.name},
+                    {
+                        "name": f"A zone with name {self.name} and no view already exists."
+                    }
                 )
 
     def clean(self, *args, **kwargs):
         self.check_name_conflict()
 
-        if self.pk is None:
-            return
-
-        old_zone = Zone.objects.get(pk=self.pk)
-        if old_zone.view == self.view and old_zone.status == self.status:
-            return
+        if self.soa_serial is None and not self.soa_serial_auto:
+            raise ValidationError(
+                {
+                    "soa_serial": f"soa_serial is not defined and soa_serial_auto is disabled for zone {self.name}."
+                }
+            )
 
     def save(self, *args, **kwargs):
-        self.check_name_conflict()
+        self.full_clean()
 
         new_zone = self.pk is None
         if not new_zone:
